@@ -89,6 +89,18 @@ def obtenirConfigurationsConsommateurDepuisVariablesEnvironnement(logger=None):
         'enable.auto.commit': consumer_enable_auto_commit,
         'default.topic.config': {'auto.offset.reset': consumer_auto_offset_reset}
     }
+    if 'KAFKA_SECURITY_PROTOCOL' in os.environ:
+        config_consommateur_kafka['security.protocol'] = os.environ['KAFKA_SECURITY_PROTOCOL']
+    if 'KAFKA_SSL_TRUSTSTORE_LOCATION' in os.environ:
+        config_consommateur_kafka['ssl.truststore.location'] = os.environ['KAFKA_SSL_TRUSTSTORE_LOCATION']
+    if 'KAFKA_SSL_TRUSTSTORE_PASSWORD' in os.environ:
+        config_consommateur_kafka['ssl.truststore.password'] = os.environ['KAFKA_SSL_TRUSTSTORE_PASSWORD']
+    if 'KAFKA_SSL_KEYSTORE_LOCATION' in os.environ:
+        config_consommateur_kafka['ssl.keystore.location'] = os.environ['KAFKA_SSL_KEYSTORE_LOCATION']
+    if 'KAFKA_SSL_KEYSTORE_PASSWORD' in os.environ:
+        config_consommateur_kafka['ssl.keystore.password'] = os.environ['KAFKA_SSL_KEYSTORE_PASSWORD']
+    if 'KAFKA_SSL_KEY_PASSWORD' in os.environ:
+        config_consommateur_kafka['ssl.key.password'] = os.environ['KAFKA_SSL_KEY_PASSWORD']
     
     config = ConfigurationConsommateurKafka(kafka=config_consommateur_kafka, max_poll_record=consumer_max_poll_records)
     
